You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@nuttx.apache.org by gn...@apache.org on 2020/04/12 13:54:42 UTC

[incubator-nuttx] branch master updated: tools/zipme.sh: Create the hashes unconditionally.

This is an automated email from the ASF dual-hosted git repository.

gnutt pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-nuttx.git


The following commit(s) were added to refs/heads/master by this push:
     new e174f73  tools/zipme.sh: Create the hashes unconditionally.
e174f73 is described below

commit e174f73010f7d42e19e135c42964f8a688a6b179
Author: Ouss4 <ab...@gmail.com>
AuthorDate: Sun Apr 12 14:58:20 2020 +0100

    tools/zipme.sh: Create the hashes unconditionally.
---
 tools/zipme.sh | 17 ++++++++++-------
 1 file changed, 10 insertions(+), 7 deletions(-)

diff --git a/tools/zipme.sh b/tools/zipme.sh
index b2aa6b6..0b8c05b 100755
--- a/tools/zipme.sh
+++ b/tools/zipme.sh
@@ -315,7 +315,16 @@ echo "Archiving and zipping apps/"
 ${TAR} ${APPS_ZIPNAME} `basename ${APPSDIR}` || \
       { echo "tar of ${APPS_ZIPNAME} failed!" ; exit 1 ; }
 
-# Finally sign the tarballs and create the digests
+# Create the hashes for the two tarballs
+
+echo "Creating the hashes"
+${SHASUM} ${NUTTX_ZIPNAME} > ${NUTTX_SHANAME} || \
+         { echo "Digest of ${NUTTX_ZIPNAME} failed!" ; exit 1 ; }
+
+${SHASUM} ${APPS_ZIPNAME} > ${APPS_SHANAME} || \
+         { echo "Digest of ${APPS_ZIPNAME} failed!" ; exit 1 ; }
+
+# Finally sign the tarballs
 
 if [ $sign != 0 ] ; then
   echo "Signing the tarballs"
@@ -324,12 +333,6 @@ if [ $sign != 0 ] ; then
 
   ${GPG} ${APPS_ZIPNAME} || \
         { echo "Signing ${APPS_ZIPNAME} failed!" ; exit 1 ; }
-
-  ${SHASUM} ${NUTTX_ZIPNAME} > ${NUTTX_SHANAME} || \
-           { echo "Digest of ${NUTTX_ZIPNAME} failed!" ; exit 1 ; }
-
-  ${SHASUM} ${APPS_ZIPNAME} > ${APPS_SHANAME} || \
-           { echo "Digest of ${APPS_ZIPNAME} failed!" ; exit 1 ; }
 fi
 
 cd ${NUTTXDIR}